@@ -218,9 +218,13 @@ try {
                             throw new Exception('No databases found for user');
                         }
                         
+                        // Log the databases found for debugging
+                        error_log("Bulk database backup for user $backupUser - Found databases: " . implode(', ', $databases));
+                        
                         $results = [];
                         foreach ($databases as $singleDb) {
                             try {
+                                error_log("Processing database backup: $singleDb");
                                 $results[] = $engine->createDatabaseBackup($backupUser, $singleDb, $targetId);
                             } catch (Exception $e) {
                                 // Log error but continue with other databases
